#
# spec file for package python-sparse
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-sparse
Version:        0.11.2
Release:        bp155.2.11
Summary:        Sparse n-dimensional arrays for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/pydata/sparse
Source:         https://files.pythonhosted.org/packages/source/s/sparse/sparse-%{version}.tar.gz
# PATCH-FIX-UPSTREAM sparse-pr421-fix-cootype.patch -- gh#pydata#sparse#421
Patch0:         %{url}/pull/421.patch#/sparse-pr421-fix-cootype.patch
BuildRequires:  %{python_module pathlib}
BuildRequires:  %{python_module setuptools}
# SECTION test requirements
BuildRequires:  %{python_module dask-array}
BuildRequires:  %{python_module numba >= 0.49}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy >= 0.19}
# /SECTION
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numba >= 0.49
Requires:       python-numpy
Requires:       python-scipy >= 0.19
BuildArch:      noarch

%python_subpackages

%description
This module implements sparse multidimensional arrays on top of NumPy and
Scipy.sparse. It generalizes the scipy.sparse.coo_matrix layout, but
extends beyond just rows and columns to an arbitrary number of
dimensions.

The original motivation is for machine learning algorithms, but it is
intended for somewhat general use.

%prep
%autosetup -p1 -n sparse-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst docs/*.rst
%license LICENSE
%{python_sitelib}/sparse
%{python_sitelib}/sparse-%{version}*-info

%changelog
* Mon Dec 28 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 0.11.2
  * Fix TypingError on sparse.dot with complex dtypes. (Issue #403,
    PR #404)
- Changelog for 0.11.1
  * Fix ValueError on sparse.dot with extremely small values.
    (Issue #398, PR #399)
- Changelog for 0.11.0
  * Improve the performance of sparse.dot. (Issue #331, PR #389,
    thanks @daletovar)
  * Added the COO.swapaxes method. (PR #344, thanks @lueckem)
  * Added multi-axis 1-D indexing support. (PR #343, thanks
    @mikeymezher)
  * Fix outer for arrays that weren’t one-dimensional. (Issue #346,
    PR #347)
  * Add casting kwarg to COO.astype. (Issue #391, PR #392)
  * Fix for COO constructor accepting invalid inputs. (Issue #385,
    PR #386)
  - Changelog for 0.10.0
  * Fixed a bug where converting an empty DOK array to COO leads to
    an incorrect dtype. (Issue #314, PR #315)
  * Change code formatter to black. (PR #284)
  * Add COO.flatten and sparse.outer. (Issue #316, PR #317).
  * Remove broadcasting restriction between sparse arrays and dense
    arrays. (Issue #306, PR #318)
  * Implement deterministic dask tokenization. (Issue #300, PR
    [#320], thanks @danielballan)
  * Improve testing around densification (PR #321, thanks
    @danielballan)
  * Simplify Numba extension. (PR #324, thanks @eric-wieser).
  * Respect copy=False in astype (PR #328, thanks @eric-wieser).
  * Replace linear_loc with ravel_multi_index, which is 3x faster.
    (PR #330, thanks @eric-wieser).
  * Add error msg to tensordot operation when ndim==0 (Issue #332,
    PR #333, thanks @guilhermeleobas).
  * Maintainence fixes for Sphinx 3.0 and Numba 0.49, and dropping
    support for Python 3.5. (PR #337).
  * Fixed signature for numpy.clip.
- Changelog for 0.9.1
  * Fixed a bug where indexing with an empty list could lead to
    issues. (Issue #281, PR #282)
  * Change code formatter to black. (PR #284)
  * Add the diagonal and diagonalize functions. (Issue #288, PR
    [#289], thanks @pettni)
  * Add HTML repr for notebooks. (PR #283, thanks @daletovar)
  * Avoid making copy of coords when making a new COO array.
  * Add stack and concatenate for GCXS. (Issue #301, PR #303,
    thanks @daletovar).
  * Fix issue where functions dispatching to an attribute access
    wouldn’t work with __array_function__. (Issue #308, PR #309).
  * Add partial support for constructing and mirroring COO objects
    to Numba.
- add sparse-pr421-fix-cootype.patch
  * gh#pydata/sparse#420
  * gh#pydata/sparse#421
* Thu Sep  5 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.8.0
  * Fixed a bug where an array with size == 1 and nnz == 0
    could not be broadcast.
  * Add ``std`` and ``var``.
  * Move to Azure Pipelines with CI for Windows, macOS and
    Linux.
  * Add ``resize``, and change ``reshape`` so it raises a
    ``ValueError`` on shapes that don't correspond to the
    same size.
  * Add ``isposinf`` and ``isneginf``.
  * Fix ``tensordot`` when nnz = 0.
  * Modifications to ``__array_function__`` to allow for sparse
    XArrays.
  * Add not-yet-public support for GCXS.
  * Improvements to ``__array_function__``.
  * Convert all Numba lists to typed lists.
  * Why write code when it exists elsewhere?
  * Fix some element-wise operations with scalars.
  * Private modules should be private, and tests should be in the package.
* Tue Apr  9 2019 pgajdos@suse.com
- version update to 0.7.0
  * python3-only package, for other changes see changelog.rst
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Update descriptions.
* Thu May 24 2018 toddrme2178@gmail.com
- Update to 0.3.1
  * Add Elementwise broadcasting and broadcast_to (:pr:`35`) `Hameer Abbasi`_
  * Add Bitwise ops (:pr:`38`) `Hameer Abbasi`_
  * Add slicing support for Ellipsis and None (:pr:`37`) `Matthew Rocklin`_
  * Add triu and tril and tests (:pr:`40`) `Hameer Abbasi`_
  * Extend gitignore file  (:pr:`42`) `Nils Werner`_
  * Update MANIFEST.in (:pr:`45`) `Matthew Rocklin`_
  * Remove auto densification and unify operator code (:pr:`46`) `Hameer Abbasi`_
  * Fix nnz for scalars (:pr:`48`) `Hameer Abbasi`_
  * Update README (:pr:`50`) (:pr:`53`) `Hameer Abbasi`_
  * Fix large concatenations and stacks (:pr:`50`) `Hameer Abbasi`_
  * Add __array_ufunc__ for __call__ and reduce (:pr:`49`) `Hameer Abbasi`_
  * Update documentation (:pr:`54`) `Hameer Abbasi`_
  * Flake8 and coverage in pytest (:pr:`59`) `Nils Werner`_
  * Copy constructor (:pr:`55`) `Nils Werner`_
  * Add random function (:pr:`41`) `Nils Werner`_
  * Add lots of indexing features (:pr:`57`) `Hameer Abbasi`_
  * Validate .transpose axes (:pr:`61`) `Nils Werner`_
  * Simplify axes normalization logic `Nils Werner`_
  * User higher density for sparse.random in tests (:pr:`64`) `Keisuke Fujii`_
  * Support left-side np.number elemwise operations (:pr:`67`) `Keisuke Fujii`_
  * Support len on COO (:pr:`68`) `Nils Werner`_
  * Update scipy version in requirements (:pr:`70`) `Hameer Abbasi`_
  * Documentation (:pr:`43`) `Nils Werner`_ and `Hameer Abbasi`_
  * Use Tox for cross Python-version testing (:pr:`77`) `Nils Werner`_
  * Support mixed sparse-dense when result is sparse (:pr:`75`) `Hameer Abbasi`_
  * Update contributing.rst (:pr:`76`) `Hameer Abbasi`_
  * Size and density properties (:pr:`69`) `Nils Werner`_
  * Fix large sum (:pr:`83`) `Hameer Abbasi`_
  * Add DOK (:pr:`85`) `Hameer Abbasi`_
  * Implement __array__ protocol (:pr:`87`) `Matthew Rocklin`_
- spec file cleanups
* Thu Nov  2 2017 arun@gmx.de
- update to version 0.1.1:
  * Add @ operator (simplify) (#16)
  * Opt in to caching
  * Cache reshape and transpose
  * Add tocsr method and sorted checking
  * Fix windows errors around int/long
  * use elemwise_binary in __add__
  * Fix bug in large reductions
  * Add out= keywords to ufuncs
* Thu May 25 2017 toddrme2178@gmail.com
- Initial version
